@@ -21,9 +21,9 @@
 
 G_BEGIN_DECLS
 
-#include <mypaint-config.h>
-#include <glib/mypaint-gegl-glib.h>
-#include <mypaint-tiled-surface.h>
+#include "mypaint-config.h"
+#include "glib/mypaint-gegl-glib.h"
+#include "mypaint-tiled-surface.h"
 
 typedef struct MyPaintGeglTiledSurface MyPaintGeglTiledSurface;
 
